package aufgabe8;

import jakarta.ejb.Stateful;

@Stateful
public class HelloWorld implements HelloWorldRemote {

    public HelloWorld() {
    }
    
    public void sayHello1() throws HelloException1 {
    	System.out.println("sH1");
    	throw new HelloException1();
    }

    public void sayHello2() throws HelloException2 {
    	System.out.println("sH2");
    	throw new HelloException2();
    }

    public void sayHello3(){
    	System.out.println("sH3");
    	int number = Integer.parseInt("Einhundertdreiundzwanzig");
    	System.out.println(number);
    }
    
    public void sayHello4(){
    	System.out.println("Hello World");
    }

}
